pub struct CourseInstance {
pub id: Uuid,
pub course_id: Uuid,
pub course_slug: String,
pub course_name: String,
pub course_description: Option<String>,
pub instance_name: Option<String>,
pub instance_description: Option<String>,
}Fields
id: Uuidcourse_id: Uuidcourse_slug: Stringcourse_name: Stringcourse_description: Option<String>instance_name: Option<String>instance_description: Option<String>Trait Implementations
Sourceimpl Debug for CourseInstance
impl Debug for CourseInstance
Sourceimpl From<CourseInstance> for CourseInstance
impl From<CourseInstance> for CourseInstance
Sourcefn from(value: CourseInstance) -> Self
fn from(value: CourseInstance) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for CourseInstance
impl JsonSchema for CourseInstance
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CourseInstance
impl RefUnwindSafe for CourseInstance
impl Send for CourseInstance
impl Sync for CourseInstance
impl Unpin for CourseInstance
impl UnwindSafe for CourseInstance