pub struct CourseInstanceInfo {
pub id: Uuid,
pub course_id: Uuid,
pub course_slug: String,
pub course_name: String,
pub course_description: Option<String>,
pub instance_name: Option<String>,
pub instance_description: Option<String>,
}Fields
id: Uuidcourse_id: Uuidcourse_slug: Stringcourse_name: Stringcourse_description: Option<String>instance_name: Option<String>instance_description: Option<String>Trait Implementations
Sourceimpl Debug for CourseInstanceInfo
impl Debug for CourseInstanceInfo
Sourceimpl JsonSchema for CourseInstanceInfo
impl JsonSchema for CourseInstanceInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CourseInstanceInfo
impl RefUnwindSafe for CourseInstanceInfo
impl Send for CourseInstanceInfo
impl Sync for CourseInstanceInfo
impl Unpin for CourseInstanceInfo
impl UnwindSafe for CourseInstanceInfo